@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import List, Optional
 import requests
 import uuid
 import base64
@@ -29,38 +29,67 @@ class File(object):
         self.request = request
         self.replaceLocalhostString = replaceLocalhostString
 
-    @staticmethod
-    def _create_block_id():
+    def _create_block_id(self):
         id = str(uuid.uuid4())
         return base64.b64encode(id.encode()).decode()
 
-    @staticmethod
-    def _get_payload(workspace_id):
-        return {
-            "operationName": "files",
-            "query": """
-                query files($where: FileWhereInput!, $recursive: Boolean) {
-                    files(where: $where, recursive: $recursive) {
+    def list_file_objects(self, workspace_id: str, recursive: bool = True):
+        # The file could indicate in 3th level, so we need indicate 2 level children field
+        query_statement = """
+            query files($where: FileWhereInput!, $recursive: Boolean) {
+                files(where: $where, recursive: $recursive) {
+                    name
+                    absolutePath
+                    size
+                    isFolder
+                    lastModified
+                    children {
                         name
                         absolutePath
                         size
                         isFolder
                         lastModified
-                        wiki
+                        children {
+                            name
+                            absolutePath
+                            size
+                            isFolder
+                            lastModified
+                        }
                     }
                 }
-            """,
-            "variables": {"where": {"workspaceId": workspace_id}, "recursive": False},
-        }
+            }"""
+        # run graphql
+        data = self.request.graphql_exec(
+            {
+                "operationName": "files",
+                "query": query_statement,
+                "variables": {
+                    "where": {"workspaceId": workspace_id},
+                    "recursive": recursive,
+                },
+            }
+        ).get("files")
 
-    def fetch(self):
-        return self.request.graphql_exec(File._get_payload(self.workspace_id)).get(
-            "files"
-        )
+        return data
 
-    def list_absolute_path(self):
-        data = self.fetch()
-        return list(map(lambda x: "/" + x["absolutePath"], data))
+    def list_absolute_path(self, recursive: bool):
+        file_objects = self.list_file_objects(self.workspace_id, recursive)
+        return self._build_absolute_path(file_objects)
+
+    def _build_absolute_path(self, file_objects: List[dict]):
+        absolute_paths = []
+        for file_object in file_objects:
+            # The object is folder and has children field
+            if file_object["isFolder"] and "children" in file_object:
+                sub_absolute_paths = self._build_absolute_path(file_object["children"])
+                absolute_paths.extend(sub_absolute_paths)
+            # if the object is file
+            if not file_object["isFolder"]:
+                absolute_path = "/" + file_object["absolutePath"]
+                absolute_paths.append(absolute_path)
+
+        return absolute_paths
 
     def _replace_localhost(self, url):
         if self.replaceLocalhostString is not None:
@@ -134,9 +163,8 @@ class File(object):
         image_wrapper = ImageWrapper(content=content)
         return image_wrapper
 
-    @staticmethod
-    async def _put_azure_block(url, file):
-        block_id = File._create_block_id()
+    async def _put_azure_block(self, url, file):
+        block_id = self._create_block_id()
         async with aiohttp.ClientSession() as session:
             async with session.put(
                 url=f"{url}&comp=block&blockId={block_id}", data=file
@@ -144,8 +172,7 @@ class File(object):
                 response.raise_for_status()
         return block_id
 
-    @staticmethod
-    def _put_azure_block_list(url, block_ids, headers):
+    def _put_azure_block_list(self, url, block_ids, headers):
         id_map = map(lambda id: f"<Latest>{id}</Latest>", block_ids)
         content = "\n".join(id_map)
         xml = """<?xml version="1.0" encoding="utf-8"?>
@@ -158,19 +185,17 @@ class File(object):
         http_response = requests.put(f"{url}&comp=blocklist", data=xml, headers=headers)
         return http_response
 
-    @staticmethod
-    async def _put_azure(url, data, headers):
+    async def _put_azure(self, url, data, headers):
         blocks = [data[i : i + BLOCK_SIZE] for i in range(0, len(data), BLOCK_SIZE)]
         block_ids = await asyncio.gather(
-            *[File._put_azure_block(url=url, file=BytesIO(block)) for block in blocks]
+            *[self._put_azure_block(url=url, file=BytesIO(block)) for block in blocks]
         )
-        http_response = File._put_azure_block_list(
+        http_response = self._put_azure_block_list(
             url=url, block_ids=block_ids, headers=headers
         )
         return http_response
 
-    @staticmethod
-    def _put(url, data, headers):
+    def _put(self, url, data, headers):
         return requests.put(url, data=data, headers=headers)
 
     def put(self, absolute_path, data):
