@@ -23,8 +23,17 @@ class TestConfig(object):
     SAMPLE_03_CP950_CSV = os.path.join(TEST_SOURCE_PATH, "test_csv_sample_03_cp950.csv")
     SAMPLE_04_UTF8_CSV = os.path.join(TEST_SOURCE_PATH, "test_csv_sample_04_utf8.csv")
 
-    SAMPLE_PARQUET_FILE = os.path.join(
-        TEST_SOURCE_PATH, "test_parquetfile_sample.parquet"
+    SAMPLE_01_MULTIPLE_TYPE_FIELDS_FORMAT_PARQUET = os.path.join(
+        TEST_SOURCE_PATH, "test_multi_types_fields_format.parquet"
+    )
+    SAMPLE_02_ONLY_TIMESTAMP_FIELDS_FORMAT_PARQUET = os.path.join(
+        TEST_SOURCE_PATH, "test_only_timestamp_fields_format.parquet"
+    )
+    SAMPLE_03_ONLY_TIMESTAMP_ZONE_FIELDS_FORMAT_PARQUET = os.path.join(
+        TEST_SOURCE_PATH, "test_only_timestamp_zone_fields_format.parquet"
+    )
+    SAMPLE_04_TIMESTAMP_WITH_TIMESTAMP_ZONE_FIELDS_FORMAT_PARQUET = os.path.join(
+        TEST_SOURCE_PATH, "test_timestamp_with_timestamp_zone_fields_format.parquet"
     )
 
     JUPYTER_SECRET = os.getenv("CANNERFLOW_JUPYTER_SECRET", "jupyter-secret")
